"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = ({ types: t, }) => ({
    name: 'react-data-testid',
    visitor: {
        Program(programPath, state) {
            var _a, _b;
            const propertyName = ((_a = state.opts) === null || _a === void 0 ? void 0 : _a.propertyName) ? state.opts.propertyName
                : 'data-test';
            const dirLevel = ((_b = state.opts) === null || _b === void 0 ? void 0 : _b.dirLevel) ? state.opts.dirLevel : 1;
            const slashChar = '/';
            const splits = state.filename.split(slashChar);
            if (!splits || !splits.length) {
                console.error('babel-plugin-add-react-test-attribute plugin error: File path is not valid.');
                return;
            }
            const dirNames = splits.slice(-1 - dirLevel, -1);
            const fileName = splits[splits.length - 1].split('.')[0];
            const fileIdentifier = `${dirNames.join('_')}_${fileName}`;
            programPath.traverse({
                JSXElement(jsxPath) {
                    let nodeName = '';
                    let dataIDDefined = false;
                    // Traverse once to get the element node name (div, Header, span, etc)
                    jsxPath.traverse({
                        JSXOpeningElement(openingPath) {
                            openingPath.stop(); // Do not visit child nodes again
                            const identifierNode = openingPath.get('name')
                                .node;
                            nodeName = identifierNode.name;
                            openingPath.traverse({
                                JSXAttribute(attributePath) {
                                    // If the data attribute doesn't exist, then we append the data attribute
                                    const attributeName = attributePath.get('name').node.name;
                                    if (!dataIDDefined) {
                                        dataIDDefined = attributeName === propertyName;
                                    }
                                },
                            });
                        },
                    });
                    if (!dataIDDefined && nodeName && nodeName !== 'Fragment') {
                        jsxPath.node.openingElement.attributes.push(t.jsxAttribute(t.jsxIdentifier(propertyName), t.stringLiteral(`${fileIdentifier}_${nodeName}`)));
                    }
                },
            });
        },
    },
});
//# sourceMappingURL=index.js.map